@@ -14,18 +14,18 @@ class Salesforce:
         self.salesforce_test_instance = salesforce_test_instance
         self.access_token, self.base_url = get_token_and_base_url(var_env_key, self.salesforce_test_instance)
         self.api_version = api_version
-
-    def get_objects(self):
-        config = yaml.load(open(self.config_file_path), Loader=yaml.FullLoader)
-        return config.get("objects")
+        self.objects = yaml.load(open(self.config_file_path), Loader=yaml.FullLoader).get('objects')
+        self.schema_prefix = yaml.load(open(self.config_file_path), Loader=yaml.FullLoader).get("schema_prefix")
 
     def get_endpoint(self):
         config = yaml.load(open(self.config_file_path), Loader=yaml.FullLoader)
         return config.get("endpoints")
 
-    def get_schema_prefix(self):
-        config = yaml.load(open(self.config_file_path), Loader=yaml.FullLoader)
-        return config.get("schema_prefix")
+    def get_table(self, _object_key):
+        _object = self.objects[_object_key]
+        if not _object.get('table'):
+            return _object_key.lower() + 's'
+        return _object.get('table')
 
     def describe_objects(self, object_name):
         headers = {
@@ -48,7 +48,7 @@ class Salesforce:
         query += ' from ' + object_name + where_clause
         return query
 
-    def execute_query(self, object_name, batch_size, since, next_records_url=None):
+    def execute_query(self, _object_key, batch_size, since, next_records_url=None):
         result = []
         headers = {
             "Authorization": "Bearer %s" % self.access_token,
@@ -56,7 +56,7 @@ class Salesforce:
             'Content-type': 'application/json'
         }
         params = {
-            "q": self.query(object_name.get('name'), since)
+            "q": self.query(_object_key, since)
         }
         url = self.base_url + "/services/data/%s/query/" % self.api_version
         if not next_records_url:
@@ -71,7 +71,7 @@ class Salesforce:
             result = result + r["records"]
             next_records_url = r.get('nextRecordsUrl')
             i = i + 1
-        return {"records": result, "object": object_name, "next_records_url": r.get('nextRecordsUrl')}
+        return {"records": result, "object": _object_key, "next_records_url": r.get('nextRecordsUrl')}
 
     def retrieve_endpoint(self, endpoint, since=None):
         headers = {
@@ -84,28 +84,31 @@ class Salesforce:
         r = requests.get(url, headers=headers, params=params).json()
         return r
 
-    def main(self, _object, schema, since=None, batchsize=100):
-        print('Starting ' + _object.get('name'))
-        if not _object.get('table'):
-            table = _object.get('name').lower() + 's'
-        else:
-            table = _object.get('table')
+    def main(self, _object_key, since=None, batchsize=10):
+        print('Starting ' + _object_key)
+
+        _object = self.objects[_object_key]
+        schema = self.schema_prefix
+        table = self.get_table(_object_key)
         next_url = None
-        if _object.get("endpoint") == True:
-            raw_data = self.retrieve_endpoint(_object.get('name'), since)
+
+        if _object.get("endpoint"):
+            raw_data = self.retrieve_endpoint(_object_key, since)
             data = process_data(raw_data)
         else:
-            raw_data = self.execute_query(_object, batchsize, since)
+            raw_data = self.execute_query(_object_key, batchsize, since)
             next_url = raw_data.get("next_records_url")
             data = process_data(raw_data["records"])
 
         columns = get_column_names(data)
-
         send_temp_data(self.dbstream, data, schema, table, columns)
+
         while next_url:
-            raw_data = self.execute_query(_object, batchsize, next_records_url=next_url, since=None)
+            raw_data = self.execute_query(_object_key, batchsize, next_records_url=next_url, since=None)
             next_url = raw_data.get("next_records_url")
             data = process_data(raw_data["records"])
             send_temp_data(self.dbstream, data, schema, table, columns)
-        print('Ended ' + _object.get('name'))
+
+        print('Ended ' + _object_key)
+
         _clean(self.dbstream, schema, table)
